pub trait Enter<'outer, TOuter: Timestamp, TInner: Timestamp + Refines<TOuter>, C> {
// Required method
fn enter<'inner>(
self,
inner: Scope<'inner, TInner>,
) -> Stream<'inner, TInner, C>;
}Expand description
Extension trait to move a Stream into a child of its current Scope.
Required Methods
Sourcefn enter<'inner>(
self,
inner: Scope<'inner, TInner>,
) -> Stream<'inner, TInner, C>
fn enter<'inner>( self, inner: Scope<'inner, TInner>, ) -> Stream<'inner, TInner, C>
Moves the Stream argument into a child of its current Scope.
The destination scope must be a child of the stream’s scope. The method checks this property at runtime, and will panic if not respected.
Examples
use timely::dataflow::operators::{Enter, Leave, ToStream};
timely::example(|outer| {
let stream = (0..9).to_stream(outer).container::<Vec<_>>();
let output = outer.region(|inner| {
stream.enter(inner).leave(outer)
});
});